package cn.com.qmth.print.manage.service.impl;

import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;

import cn.com.qmth.print.manage.dao.ExamStudentDao;
import cn.com.qmth.print.manage.entity.ExamStudentEntity;
import cn.com.qmth.print.manage.enums.GroupType;
import cn.com.qmth.print.manage.service.ExamStudentService;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.boot.core.exception.StatusException;

@Service
public class ExamStudentServiceImpl extends ServiceImpl<ExamStudentDao, ExamStudentEntity> implements
        ExamStudentService {

    @Override
    public ExamStudentEntity findByExamIdAndExamNumber(Long examId, String startNumber) {
        if (examId == null) {
            throw new StatusException("examId不能为空");
        }
        if (StringUtils.isEmpty(startNumber)) {
            throw new StatusException("准考证号不能为空");
        }
        QueryWrapper<ExamStudentEntity> wrapper = new QueryWrapper<>();
        LambdaQueryWrapper<ExamStudentEntity> lw = wrapper.lambda();
        lw.eq(ExamStudentEntity::getExamId, examId);
        lw.eq(ExamStudentEntity::getExamNumber, startNumber);
        ExamStudentEntity entity = this.getOne(wrapper);
        return entity;
    }

    @Override
    public Long findSortNoByExamIdAndGroupTypeAndSort(Long examId, GroupType type, String groupName, boolean isAse) {
        QueryWrapper<ExamStudentEntity> wrapper = new QueryWrapper<>();
        LambdaQueryWrapper<ExamStudentEntity> lw = wrapper.lambda();
        lw.eq(ExamStudentEntity::getExamId, examId);
        if (GroupType.COURSE.equals(type)) {
            lw.eq(ExamStudentEntity::getCourseCode, groupName);
        } else if (GroupType.EXAM_SITE.equals(type)) {
            lw.eq(ExamStudentEntity::getExamSite, groupName);
        } else if (GroupType.EXAM_ROOM.equals(type)) {
            lw.eq(ExamStudentEntity::getExamRoom, groupName);
        }
        if (isAse) {
            wrapper.orderByAsc("sort_no");
        } else {
            wrapper.orderByDesc("sort_no");
        }
        wrapper.last("LIMIT 1");
        ExamStudentEntity entity = this.getOne(wrapper);
        return entity.getSortNo();
    }
}
